/*
 * Copyright 2017 salesforce.com, inc.
 * All rights reserved.
 *
 * Use of this software is subject to the salesforce.com Developerforce Terms of
 * Use and other applicable terms that salesforce.com may make available, as may be
 * amended from time to time. You may not decompile, reverse engineer, disassemble,
 * attempt to derive the source code of, decrypt, modify, or create derivative
 * works of this software, updates thereto, or any part thereof. You may not use
 * the software to engage in any development activity that infringes the rights of
 * a third party, including that which interferes with, damages, or accesses in an
 * unauthorized manner the servers, networks, or other properties or services of
 * salesforce.com or any third party.
 *
 * WITHOUT LIMITING THE GENERALITY OF THE FOREGOING, THE SOFTWARE IS PROVIDED
 * "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED. IN NO EVENT SHALL
 * SALESFORCE.COM HAVE ANY LIABILITY FOR ANY DAMAGES, INCLUDING BUT NOT LIMITED TO,
 * DIRECT, INDIRECT, SPECIAL, INCIDENTAL, PUNITIVE, OR CONSEQUENTIAL DAMAGES, OR
 * DAMAGES BASED ON LOST PROFITS, DATA OR USE, IN CONNECTION WITH THE SOFTWARE,
 * HOWEVER CAUSED AND, WHETHER IN CONTRACT, TORT OR UNDER ANY OTHER THEORY OF
 * LIABILITY, WHETHER OR NOT YOU HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGES.
 */

#import <Foundation/Foundation.h>
#import <ServiceSOS/SOSNetworkReporterDelegate.h>

NS_ASSUME_NONNULL_BEGIN

/**
 * SOS Network Reporter to manage delegates which receive information about SOS Audio/Video networking events.
 *
 * Please note that the information related here refers to network information about the agent's connection experience.
 */
@interface SOSNetworkReporter : NSObject

/**
 *  Adds an instance of an `NSObject` implementing the `SOSNetworkReporterDelegate` protocol to the list of delegates to notify.
 *
 *  @param delegate `NSObject` instance to add.
 */
- (void)addDelegate:(id<SOSNetworkReporterDelegate>)delegate;

/**
 *  Removes an instance of an `NSObject` implementing the `SOSNetworkReporterDelegate` protocol to the list of delegates to notify.
 *
 *  @param delegate `NSObject` instance to remove.
 */
- (void)removeDelegate:(id<SOSNetworkReporterDelegate>)delegate;

@end

NS_ASSUME_NONNULL_END
